==> fetch.php?media=download_software:mae3xx:mae3xx_rootfs_bionic_v4_0_0.tar.xz: opt/mae3xx/app/AppServer/Handlers/Interface.py <==
# -*- coding: utf-8 -*-

from Handlers import BaseHandler
from IPy import IP
import shutil
import os
#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class Interface(BaseHandler.BaseHandler):
    #=======================================================
    # 
    #=======================================================
    def __init__(self):
        self.config = '/etc/network/interfaces'
        self.pre_conf = '/tmp/interfaces'
        self.name = 'Interface'
        self.interface = ['eth0', 'eth1', 'br0']
        self.addressFields = ['address', 'netmask']
        self.AUTO = 'auto %s \n'
        self.IFACE = 'iface %s inet %s\n'
        self.CMD = '\t%s %s\n'
        self.DNS = '\tdns-nameservers %s %s\n'
        self.BRIDGE = '\tbridge_ports eth0 eth1\n\tbridge_stp off\n\tbridge_maxwait 1\n'
        self.PRE = '\tpre-up   ifconfig $IFACE up\n\tpre-down ifconfig $IFACE down\n'
        self.GATEWAY = '\nup route add default gw %s\n'
    #=======================================================
    # 
    #=======================================================
    def Get(self, request):

        status = 200
        return self.readInterfaces(), status
    
    #=======================================================
    # 
    #=======================================================
    def Put(self, request):
        
        status = self.validator(request.json)

        if status == 200:
            delbr = False
            if self.call(['ifconfig', 'br0']) == 0 and request.json['common']['bridge'] =='false':
                delbr = True

            self.writeInterfaces(request.json, delbr)
            self.restartInterface(delbr, request.json)

        return status

    #=======================================================
    # 
    #=======================================================
    def readInterfaces(self):

        config = {}

        interfaces = open(self.config, "r")

        for interface in self.interface:
            config[interface] = {'getaddress':'', 'address':'', 'netmask':''}
        config['common'] = {'gateway':'', 'pridns':'','secdns':'', 'pppoe':'false'}

        for line in interfaces:
            if line.startswith('#'):
                pass
            else:

                if line.startswith('iface'):
                    sline = line.split()
                    interface = sline[1]
                    if interface in config:
                        config[interface]["getaddress"] = sline[3]
                    else:
                        interface = ''
                elif line.startswith('up route'):
                    sline = line.strip('\n').split()
                    config['common']['gateway'] = sline[5]
                    
                elif line.isspace():
                    pass
                elif interface:
                    sline = line.split()
                    if sline[0] == 'address':
                        config[interface]["address"] = sline[1]
                    elif sline[0] == 'netmask':
                        config[interface]["netmask"] = sline[1]
                    elif sline[0] == 'gateway':
                        config[interface]["gateway"] = sline[1]
                    elif sline[0] == 'dns-nameservers':
                        config['common']["pridns"] = sline[1]
                        if len(sline) > 2:
                            config['common']["secdns"] = sline[2]

            if config['br0']['address'] and config['br0']['address'] !='0.0.0.0':
                config['common']['bridge'] = 'true'
            else:
                config['common']['bridge'] = 'false'
        if os.path.exists('/etc/network/interfaces.d/dsl-provider'):
            config['common']['pppoe'] = 'true'

        return config

    #=======================================================
    # 
    #=======================================================
    def writeInterfaces(self, args, delbr):

        if delbr:
            conf_file = self.pre_conf
        else :
            conf_file = self.config


        config = open(conf_file, "w")
        config.write("# interfaces(5) file used by ifup(8) and ifdown(8)\n# Include files from\ /etc/network/interfaces.d:\nsource-directory /etc/network/interfaces.d\n")
        config.write(self.AUTO % 'lo')
        config.write(self.IFACE % ('lo', 'loopback'))

        if args['common']['bridge'] == 'true':
            for interface in self.interface:
                config.write(self.AUTO % interface)
                if interface == 'br0':
                    config.write(self.IFACE % (interface,args[interface]['getaddress']))
                    for key in self.addressFields:
                        if args[interface][key]:
                            config.write(self.CMD % (key, args[interface][key]))
                    if args['common']['pridns']:
                        config.write(self.DNS % ( args['common']['pridns'], args['common']['secdns']))
                    config.write(self.BRIDGE)
                else:
                    config.write(self.IFACE % (interface, 'manual'))
                    config.write(self.PRE)
        else:
            #for interface in self.interface:
            for interface in ['eth0', 'eth1']:
                config.write(self.AUTO % interface)
                config.write(self.IFACE % (interface, args[interface]['getaddress']))
                for key in self.addressFields:
                    if args[interface][key]:
                        config.write(self.CMD % (key, args[interface][key]))
                if args['common']['pridns']:
                    config.write(self.DNS % ( args['common']['pridns'], args['common']['secdns']))
                config.write(self.PRE)
        if args['common']['gateway']:
            config.write(self.GATEWAY % args['common']['gateway'])

        config.close()

    #=======================================================
    # 
    #=======================================================
    def restartInterface(self, delbr, args):
        
        if delbr:
            self.call(['ifdown', 'br0'])
            shutil.move(self.pre_conf, self.config)
        
        self.call("ifdown --exclude=lo -a && ifup --exclude=lo -a",  shell=True)
        self.service('dnsmasq', 'restart')
        if args['common']['gateway']:
            self.call('route add default gw %s' % args['common']['gateway'], shell=True)

    #=======================================================
    # 
    #=======================================================
    def validator(self, args):

        result = 400

        # check ipaddr 
        if args['common']['bridge'] == 'false':
            interfaces = ['eth0', 'eth1']
        else:
            interfaces = ['br0']
            if os.path.exists('/etc/network/interfaces.d/dsl-provider'):
                self.log('PPPoE connected. bridge interface not used. ')
                return 409

        for interface in interfaces:
            if args[interface]['getaddress'] == 'static':
                if args[interface]['address'] != '0.0.0.0':
                    if not self.check_ipaddr(args[interface]['address']):
                        return result
                if args[interface]['netmask'] == '':
                        return result

        # check reachable gateway 
        if args['common']['gateway']:
            if args['common']['bridge'] == 'false':
                interfaces = ['eth0', 'eth1']
            else:
                interfaces = ['br0']

            for interface in interfaces:
                if args[interface]['getaddress'] == 'static':
                    if (IP(args[interface]['address']).make_net(args[interface]['netmask'])).overlaps(args['common']['gateway']):
                        result = 200
        else:
            result = 200

        return result

==> fetch.php?media=download_software:mae3xx:mae3xx_rootfs_bionic_v4_2_1.tar.xz: opt/mae3xx/app/AppServer/Handlers/Interface.py <==
# -*- coding: utf-8 -*-

from Handlers import BaseHandler
from IPy import IP
import shutil
import os
#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class Interface(BaseHandler.BaseHandler):
    #=======================================================
    # 
    #=======================================================
    def __init__(self):
        self.config = '/etc/network/interfaces'
        self.pre_conf = '/tmp/interfaces'
        self.name = 'Interface'
        self.interface = ['eth0', 'eth1', 'br0']
        self.addressFields = ['address', 'netmask']
        self.AUTO = 'auto %s \n'
        self.IFACE = 'iface %s inet %s\n'
        self.CMD = '\t%s %s\n'
        self.DNS = '\tdns-nameservers %s %s\n'
        self.BRIDGE = '\tbridge_ports eth0 eth1\n\tbridge_stp off\n\tbridge_maxwait 1\n'
        self.PRE = '\tpre-up   ifconfig $IFACE up\n\tpre-down ifconfig $IFACE down\n'
        self.GATEWAY = '\nup route add default gw %s\n'
    #=======================================================
    # 
    #=======================================================
    def Get(self, request):

        status = 200
        return self.readInterfaces(), status
    
    #=======================================================
    # 
    #=======================================================
    def Put(self, request):
        
        status = self.validator(request.json)

        if status == 200:
            delbr = False
            if self.call(['ifconfig', 'br0']) == 0 and request.json['common']['bridge'] =='false':
                delbr = True

            self.writeInterfaces(request.json, delbr)
            self.restartInterface(delbr, request.json)

        return status

    #=======================================================
    # 
    #=======================================================
    def readInterfaces(self):

        config = {}

        interfaces = open(self.config, "r")

        for interface in self.interface:
            config[interface] = {'getaddress':'', 'address':'', 'netmask':''}
        config['common'] = {'gateway':'', 'pridns':'','secdns':'', 'pppoe':'false'}

        for line in interfaces:
            if line.startswith('#'):
                pass
            else:

                if line.startswith('iface'):
                    sline = line.split()
                    interface = sline[1]
                    if interface in config:
                        config[interface]["getaddress"] = sline[3]
                    else:
                        interface = ''
                elif line.startswith('up route'):
                    sline = line.strip('\n').split()
                    config['common']['gateway'] = sline[5]
                    
                elif line.isspace():
                    pass
                elif interface:
                    sline = line.split()
                    if sline[0] == 'address':
                        config[interface]["address"] = sline[1]
                    elif sline[0] == 'netmask':
                        config[interface]["netmask"] = sline[1]
                    elif sline[0] == 'gateway':
                        config[interface]["gateway"] = sline[1]
                    elif sline[0] == 'dns-nameservers':
                        config['common']["pridns"] = sline[1]
                        if len(sline) > 2:
                            config['common']["secdns"] = sline[2]

            if config['br0']['address'] and config['br0']['address'] !='0.0.0.0':
                config['common']['bridge'] = 'true'
            else:
                config['common']['bridge'] = 'false'
        if os.path.exists('/etc/network/interfaces.d/dsl-provider'):
            config['common']['pppoe'] = 'true'

        return config

    #=======================================================
    # 
    #=======================================================
    def writeInterfaces(self, args, delbr):


        self.call("ifdown --exclude=lo -a",  shell=True)

        conf_file = self.config
        config = open(conf_file, "w")
        config.write("# interfaces(5) file used by ifup(8) and ifdown(8)\n# Include files from\ /etc/network/interfaces.d:\nsource-directory /etc/network/interfaces.d\n")
        config.write(self.AUTO % 'lo')
        config.write(self.IFACE % ('lo', 'loopback'))

        if args['common']['bridge'] == 'true':
            for interface in self.interface:
                config.write(self.AUTO % interface)
                if interface == 'br0':
                    config.write(self.IFACE % (interface,args[interface]['getaddress']))
                    for key in self.addressFields:
                        if args[interface][key]:
                            config.write(self.CMD % (key, args[interface][key]))
                    if args['common']['pridns']:
                        config.write(self.DNS % ( args['common']['pridns'], args['common']['secdns']))
                    config.write(self.BRIDGE)
                else:
                    config.write(self.IFACE % (interface, 'manual'))
        else:
            #for interface in self.interface:
            for interface in ['eth0', 'eth1']:
                config.write(self.AUTO % interface)
                config.write(self.IFACE % (interface, args[interface]['getaddress']))
                for key in self.addressFields:
                    if args[interface][key]:
                        config.write(self.CMD % (key, args[interface][key]))
                if args['common']['pridns']:
                    config.write(self.DNS % ( args['common']['pridns'], args['common']['secdns']))
        if args['common']['gateway']:
            config.write(self.GATEWAY % args['common']['gateway'])

        config.close()

    #=======================================================
    # 
    #=======================================================
    def restartInterface(self, delbr, args):
        
        self.call("ifup --exclude=lo -a",  shell=True)
        self.service('dnsmasq', 'restart')
        if args['common']['gateway']:
            self.call('route add default gw %s' % args['common']['gateway'], shell=True)

    #=======================================================
    # 
    #=======================================================
    def validator(self, args):

        result = 400

        # check ipaddr 
        if args['common']['bridge'] == 'false':
            interfaces = ['eth0', 'eth1']
        else:
            interfaces = ['br0']
            if os.path.exists('/etc/network/interfaces.d/dsl-provider'):
                self.log('PPPoE connected. bridge interface not used. ')
                return 409

        for interface in interfaces:
            if args[interface]['getaddress'] == 'static':
                if args[interface]['address'] != '0.0.0.0':
                    if not self.check_ipaddr(args[interface]['address']):
                        return result
                if args[interface]['netmask'] == '':
                        return result

        # check reachable gateway 
        if args['common']['gateway']:
            if args['common']['bridge'] == 'false':
                interfaces = ['eth0', 'eth1']
            else:
                interfaces = ['br0']

            for interface in interfaces:
                if args[interface]['getaddress'] == 'static':
                    if (IP(args[interface]['address']).make_net(args[interface]['netmask'])).overlaps(args['common']['gateway']):
                        result = 200
        else:
            result = 200

        return result
